@@ -18,7 +18,7 @@ sub import {
     TCOD::Event->import::into( scalar caller );
 }
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 my $bundle = FFI::Platypus->new( api => 1 );
 $bundle->bundle('TCOD');
@@ -400,7 +400,8 @@ $ffi->type( int    => 'TCOD_renderer' );
 $ffi->type( int    => 'TCOD_keycode'  );
 $ffi->type( int    => 'TCOD_error'    );
 $ffi->type( opaque => 'TCOD_event'    );
-$ffi->type( '(int, int, int, int, opaque )->float' => 'TCOD_path_func' );
+$ffi->type( '(int, int, int, int, opaque )->float' => 'TCOD_path_func'     );
+$ffi->type( '(int,int)->bool'                      => 'TCOD_line_listener' );
 
 # Custom blessed opaque types
 for my $name (qw( image console map path dijkstra random noise context )) {
@@ -570,8 +571,8 @@ package TCOD::Color {
 package TCOD::ColorRGBA {
     use FFI::Platypus::Record;
     record_layout_1( uint8 => 'r', uint8 => 'g', uint8 => 'b', uint8 => 'a' );
-    $ffi->type( 'record(TCOD::ColorRGBA)'  => 'TCOD_colorRGBA'  );
-    $bundle->type( 'record(TCOD::ColorRGBA)'  => 'TCOD_colorRGBA'  );
+       $ffi->type( 'record(TCOD::ColorRGBA)' => 'TCOD_colorRGBA' );
+    $bundle->type( 'record(TCOD::ColorRGBA)' => 'TCOD_colorRGBA' );
 
     {
         # Give color a positional constructor
@@ -1133,7 +1134,10 @@ package
         tcod_version      => 'int',
         keep_aspect       => 'bool',
         integer_scaling   => 'bool',
-        _clear_color      => 'opaque', # TCOD_ColorRGBA
+        _clear_color_r    => 'uint8',
+        _clear_color_g    => 'uint8',
+        _clear_color_b    => 'uint8',
+        _clear_color_a    => 'uint8',
         align_x           => 'float',
         align_y           => 'float',
     ]);
@@ -1190,7 +1194,7 @@ package TCOD::Context {
         sub new_console {
             my ( $self, %args ) = ( shift );
 
-            # Accommodate $ctx->present( $cols, $rows, $magnification );
+            # Accommodate $ctx->new_console( $cols, $rows, $magnification );
             %args = ( min_columns => shift, min_rows => shift, magnification => shift ) if @_ % 2;
             %args = ( %args, @_ );
 
@@ -1223,9 +1227,10 @@ package TCOD::Context {
 
         my $c = delete $args{clear_color} // TCOD::BLACK();
 
-        $args{_clear_color} = $ffi->cast(
-            TCOD_colorRGBA => opaque => TCOD::ColorRGBA->new( $c->r, $c->g, $c->b, 0xFF ),
-        );
+        $args{_clear_color_r} = $c->r;
+        $args{_clear_color_g} = $c->g;
+        $args{_clear_color_b} = $c->b;
+        $args{_clear_color_a} = 0xFF;
 
         my $err = $xsub->( $self, delete $args{console}, TCOD::ViewportOptions->new(\%args) );
         Carp::croak TCOD::get_error() if $err < 0;
@@ -1273,6 +1278,22 @@ package TCOD::Context {
     $ffi->attach( [ TCOD_context_delete => 'DESTROY' ] => ['TCOD_context'] => 'void' );
 }
 
+package TCOD::Line {
+    $ffi->mangler( sub { shift } );
+
+    $ffi->attach( [ TCOD_line => 'bresenham' ] => [qw( int int int int TCOD_line_listener )] => bool => sub {
+        my ( $xsub, $x1, $y1, $x2, $y2, $cb ) = @_;
+
+        my @out;
+        $cb //= sub { push @out, [ @_ ]; 1 };
+
+        my $closure = $ffi->closure( $cb );
+        $xsub->( $x1, $y1, $x2, $y2, $closure );
+
+        @out;
+    });
+}
+
 for (
     # color values
     [ BLACK                  => [   0,   0,   0 ] ],
